from a10sdk.common.A10BaseClass import A10BaseClass


class CipherWithoutPrioList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cipher_wo_prio: {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cipher-without-prio-list"
        self.DeviceProxy = ""
        self.cipher_wo_prio = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServerCertificateError(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param error_type: {"enum": ["email", "ignore", "logging", "trap"], "type": "string", "description": "'email': Notify the error via email; 'ignore': Ignore the error, which mean the connection can continue; 'logging': Log the error; 'trap': Notify the error by SNMP trap; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "server-certificate-error"
        self.DeviceProxy = ""
        self.error_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CaCerts(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ca_cert: {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify CA certificate", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ca-certs"
        self.DeviceProxy = ""
        self.ca_cert = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServerSsl(A10BaseClass):
    
    """Class Description::
    Server Side SSL Template.

    Class server-ssl supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param session_cache_timeout: {"description": "Session Cache Timeout (Timeout value, in seconds)", "format": "number", "type": "number", "maximum": 7200, "minimum": 1, "optional": true}
    :param name: {"description": "Server SSL Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param session_cache_size: {"description": "Session Cache Size (Specify 0 to disable Session ID reuse.)", "format": "number", "type": "number", "maximum": 128, "minimum": 0, "optional": true}
    :param encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param cipher_template: {"description": "Cipher Template (Cipher Config Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param session_ticket_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable server side session ticket support", "format": "flag"}
    :param cert: {"description": "Specify Client certificate (Certificate Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param version: {"description": "TLS/SSL version, default is TLS1.0 (TLS/SSL version: 30-SSLv3.0, 31-TLSv1.0, 32-TLSv1.1 and 33-TLSv1.2)", "format": "number", "type": "number", "maximum": 33, "minimum": 30, "optional": true}
    :param forward_proxy_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable SSL forward proxy", "format": "flag"}
    :param close_notify: {"default": 0, "optional": true, "type": "number", "description": "Send close notification when terminate connection", "format": "flag"}
    :param key: {"description": "Client private-key (Key Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param cipher_without_prio_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cipher-wo-prio": {"enum": ["SSL3_RSA_DES_192_CBC3_SHA", "SSL3_RSA_DES_40_CBC_SHA", "SSL3_RSA_DES_64_CBC_SHA", "SSL3_RSA_RC4_128_MD5", "SSL3_RSA_RC4_128_SHA", "SSL3_RSA_RC4_40_MD5", "TLS1_RSA_AES_128_SHA", "TLS1_RSA_AES_256_SHA", "TLS1_RSA_EXPORT1024_RC4_56_MD5", "TLS1_RSA_EXPORT1024_RC4_56_SHA", "TLS1_RSA_AES_128_SHA256", "TLS1_RSA_AES_256_SHA256"], "type": "string", "description": "'SSL3_RSA_DES_192_CBC3_SHA': SSL3_RSA_DES_192_CBC3_SHA; 'SSL3_RSA_DES_40_CBC_SHA': SSL3_RSA_DES_40_CBC_SHA; 'SSL3_RSA_DES_64_CBC_SHA': SSL3_RSA_DES_64_CBC_SHA; 'SSL3_RSA_RC4_128_MD5': SSL3_RSA_RC4_128_MD5; 'SSL3_RSA_RC4_128_SHA': SSL3_RSA_RC4_128_SHA; 'SSL3_RSA_RC4_40_MD5': SSL3_RSA_RC4_40_MD5; 'TLS1_RSA_AES_128_SHA': TLS1_RSA_AES_128_SHA; 'TLS1_RSA_AES_256_SHA': TLS1_RSA_AES_256_SHA; 'TLS1_RSA_EXPORT1024_RC4_56_MD5': TLS1_RSA_EXPORT1024_RC4_56_MD5; 'TLS1_RSA_EXPORT1024_RC4_56_SHA': TLS1_RSA_EXPORT1024_RC4_56_SHA; 'TLS1_RSA_AES_128_SHA256': TLS1_RSA_AES_128_SHA256; 'TLS1_RSA_AES_256_SHA256': TLS1_RSA_AES_256_SHA256; ", "format": "enum"}, "optional": true}}]}
    :param passphrase: {"description": "Password Phrase", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param server_certificate_error: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"error-type": {"enum": ["email", "ignore", "logging", "trap"], "type": "string", "description": "'email': Notify the error via email; 'ignore': Ignore the error, which mean the connection can continue; 'logging': Log the error; 'trap': Notify the error by SNMP trap; ", "format": "enum"}, "optional": true}}]}
    :param ca_certs: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ca-cert": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Specify CA certificate", "format": "string"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/server-ssl/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "server-ssl"
        self.a10_url="/axapi/v3/slb/template/server-ssl/{name}"
        self.DeviceProxy = ""
        self.session_cache_timeout = ""
        self.name = ""
        self.session_cache_size = ""
        self.encrypted = ""
        self.cipher_template = ""
        self.session_ticket_enable = ""
        self.cert = ""
        self.version = ""
        self.forward_proxy_enable = ""
        self.close_notify = ""
        self.key = ""
        self.cipher_without_prio_list = []
        self.passphrase = ""
        self.server_certificate_error = []
        self.ca_certs = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ClearCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param clear_sequence: {"description": "Specify the port physical port number", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param clear_all_sequence: {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param sessions: {"enum": ["all", "sequence"], "type": "string", "description": "'all': Clear all sessions; 'sequence': Sequence number; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "clear-cfg"
        self.DeviceProxy = ""
        self.clear_sequence = ""
        self.clear_all_sequence = ""
        self.sessions = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LinkEnableCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ena_sequence: {"description": "Sequence number (Specify the physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param enaeth: {"type": "number", "description": "Specify the physical port number (Ethernet interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "link-enable-cfg"
        self.DeviceProxy = ""
        self.ena_sequence = ""
        self.enaeth = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LinkUpCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param linkup_ethernet3: {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}
    :param linkup_ethernet2: {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}
    :param linkup_ethernet1: {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}
    :param link_up_sequence1: {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param link_up_sequence3: {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param link_up_sequence2: {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "link-up-cfg"
        self.DeviceProxy = ""
        self.linkup_ethernet3 = ""
        self.linkup_ethernet2 = ""
        self.linkup_ethernet1 = ""
        self.link_up_sequence1 = ""
        self.link_up_sequence3 = ""
        self.link_up_sequence2 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LinkDownCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param link_down_sequence1: {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param link_down_sequence2: {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param link_down_sequence3: {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param linkdown_ethernet2: {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}
    :param linkdown_ethernet3: {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}
    :param linkdown_ethernet1: {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "link-down-cfg"
        self.DeviceProxy = ""
        self.link_down_sequence1 = ""
        self.link_down_sequence2 = ""
        self.link_down_sequence3 = ""
        self.linkdown_ethernet2 = ""
        self.linkdown_ethernet3 = ""
        self.linkdown_ethernet1 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LinkDisableCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dis_sequence: {"description": "Sequence number (Specify the physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}
    :param diseth: {"type": "number", "description": "Specify the physical port number (Ethernet interface number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "link-disable-cfg"
        self.DeviceProxy = ""
        self.dis_sequence = ""
        self.diseth = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Monitor(A10BaseClass):
    
    """Class Description::
    Monitor template.

    Class monitor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param clear_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"clear-sequence": {"description": "Specify the port physical port number", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "clear-all-sequence": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true, "sessions": {"enum": ["all", "sequence"], "type": "string", "description": "'all': Clear all sessions; 'sequence': Sequence number; ", "format": "enum"}}}]}
    :param link_enable_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ena-sequence": {"description": "Sequence number (Specify the physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "enaeth": {"type": "number", "description": "Specify the physical port number (Ethernet interface number)", "format": "interface"}, "optional": true}}]}
    :param link_up_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"linkup-ethernet3": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkup-ethernet2": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkup-ethernet1": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "link-up-sequence1": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-up-sequence3": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-up-sequence2": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true}}]}
    :param link_down_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"link-down-sequence1": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-down-sequence2": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "link-down-sequence3": {"description": "Sequence number (Specify the port physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "optional": true, "linkdown-ethernet2": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkdown-ethernet3": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}, "linkdown-ethernet1": {"type": "number", "description": "Specify the port physical port number (Ethernet interface number)", "format": "interface"}}}]}
    :param link_disable_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dis-sequence": {"description": "Sequence number (Specify the physical port number)", "minimum": 1, "type": "number", "maximum": 16, "format": "number"}, "diseth": {"type": "number", "description": "Specify the physical port number (Ethernet interface number)", "format": "interface"}, "optional": true}}]}
    :param monitor_relation: {"description": "'monitor-and': Configures the monitors in current template to work with AND logic; 'monitor-or': Configures the monitors in current template to work with OR logic; ", "format": "enum", "default": "monitor-and", "type": "string", "enum": ["monitor-and", "monitor-or"], "optional": true}
    :param id: {"description": "Monitor template ID Number", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/monitor/{id}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "id"]

        self.b_key = "monitor"
        self.a10_url="/axapi/v3/slb/template/monitor/{id}"
        self.DeviceProxy = ""
        self.clear_cfg = []
        self.link_enable_cfg = []
        self.link_up_cfg = []
        self.link_down_cfg = []
        self.link_disable_cfg = []
        self.monitor_relation = ""
        self.A10WW_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Gslb(A10BaseClass):
    
    """Class Description::
    Enable GSLB group traps.

    Class gslb supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param all: {"default": 0, "optional": true, "type": "number", "description": "Enable all GSLB traps", "format": "flag"}
    :param service_ip: {"default": 0, "optional": true, "type": "number", "description": "Enable GSLB service-ip related traps", "format": "flag"}
    :param group: {"default": 0, "optional": true, "type": "number", "description": "Enable GSLB group related traps", "format": "flag"}
    :param site: {"default": 0, "optional": true, "type": "number", "description": "Enable GSLB site related traps", "format": "flag"}
    :param zone: {"default": 0, "optional": true, "type": "number", "description": "Enable GSLB zone related traps", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/gslb`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "gslb"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/gslb"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.service_ip = ""
        self.group = ""
        self.site = ""
        self.zone = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RuleList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param operation: {"enum": ["no-access", "read", "write"], "type": "string", "description": "'no-access': no-access; 'read': read; 'write': write; ", "format": "enum"}
    :param object: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Lineage of object class for permitted operation", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rule-list"
        self.DeviceProxy = ""
        self.operation = ""
        self.A10WW_object = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Role(A10BaseClass):
    
    """Class Description::
    Role configuration for RBA support.

    Class role supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Name for the RBA role", "format": "string", "minLength": 1, "optional": false, "maxLength": 32, "type": "string"}
    :param rule_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"operation": {"enum": ["no-access", "read", "write"], "type": "string", "description": "'no-access': no-access; 'read': read; 'write': write; ", "format": "enum"}, "object": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Lineage of object class for permitted operation", "format": "string"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/rba/role/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "role"
        self.a10_url="/axapi/v3/rba/role/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.rule_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Address(A10BaseClass):
    
    """Class Description::
    Configure agent address used in sFlow datagram, default use management IP address.

    Class address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip: {"not": "ipv6", "optional": true, "type": "string", "description": "Configure sFlow agent IP address", "format": "ipv4-address"}
    :param ipv6: {"not": "ip", "optional": true, "type": "string", "description": "Configure sFlow agent IPv6 address", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/sflow/agent/address`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "address"
        self.a10_url="/axapi/v3/sflow/agent/address"
        self.DeviceProxy = ""
        self.ip = ""
        self.ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class BwList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param action: {"enum": ["create", "import", "export", "copy", "rename", "check", "replace", "delete"], "type": "string", "description": "'create': create; 'import': import; 'export': export; 'copy': copy; 'rename': rename; 'check': check; 'replace': replace; 'delete': delete; ", "format": "enum"}
    :param dst_file: {"minLength": 1, "maxLength": 32, "type": "string", "description": "destination file name for copy and rename action", "format": "string"}
    :param file_handle: {"minLength": 1, "maxLength": 255, "type": "string", "description": "full path of the uploaded file", "format": "string-rlx"}
    :param file: {"minLength": 1, "maxLength": 63, "type": "string", "description": "bw-list file name", "format": "string"}
    :param size: {"type": "number", "description": "bw-list file size in byte", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bw-list"
        self.DeviceProxy = ""
        self.action = ""
        self.dst_file = ""
        self.file_handle = ""
        self.A10WW_file = ""
        self.size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpMapList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param action: {"enum": ["create", "import", "export", "copy", "rename", "check", "replace", "delete"], "type": "string", "description": "'create': create; 'import': import; 'export': export; 'copy': copy; 'rename': rename; 'check': check; 'replace': replace; 'delete': delete; ", "format": "enum"}
    :param dst_file: {"minLength": 1, "maxLength": 32, "type": "string", "description": "destination file name for copy and rename action", "format": "string"}
    :param file_handle: {"minLength": 1, "maxLength": 255, "type": "string", "description": "full path of the uploaded file", "format": "string-rlx"}
    :param file: {"minLength": 1, "maxLength": 63, "type": "string", "description": "ip map list file name", "format": "string"}
    :param size: {"type": "number", "description": "ip map list file size in byte", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-map-list"
        self.DeviceProxy = ""
        self.action = ""
        self.dst_file = ""
        self.file_handle = ""
        self.A10WW_file = ""
        self.size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ClassList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param action: {"enum": ["create", "import", "export", "copy", "rename", "check", "replace", "delete"], "type": "string", "description": "'create': create; 'import': import; 'export': export; 'copy': copy; 'rename': rename; 'check': check; 'replace': replace; 'delete': delete; ", "format": "enum"}
    :param dst_file: {"minLength": 1, "maxLength": 32, "type": "string", "description": "destination file name for copy and rename action", "format": "string"}
    :param file_handle: {"minLength": 1, "maxLength": 255, "type": "string", "description": "full path of the uploaded file", "format": "string-rlx"}
    :param file: {"minLength": 1, "maxLength": 63, "type": "string", "description": "class list local file name", "format": "string"}
    :param size: {"type": "number", "description": "class list file size in byte", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "class-list"
        self.DeviceProxy = ""
        self.action = ""
        self.dst_file = ""
        self.file_handle = ""
        self.A10WW_file = ""
        self.size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class File(A10BaseClass):
    
    """Class Description::
    Local file Mangement.

    Class file supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/file`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "file"
        self.a10_url="/axapi/v3/file"
        self.DeviceProxy = ""
        self.ssl_cert_key = {}
        self.bw_list = {}
        self.ip_map_list = {}
        self.syslog = {}
        self.health_external = {}
        self.auth_portal = {}
        self.aflex = {}
        self.health_postfile = {}
        self.ssl_crl = {}
        self.debug_monitor = {}
        self.policy = {}
        self.auth_portal_image = {}
        self.class_list = {}
        self.dnssec_ds = {}
        self.local_uri_file = {}
        self.wsdl = {}
        self.ssl_key = {}
        self.A10WW_license = {}
        self.ca_cert = {}
        self.axdebug = {}
        self.xml_schema = {}
        self.startup_config = {}
        self.auth_saml_idp = {}
        self.ssl_cert = {}
        self.dnssec_dnskey = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class NotificationCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param notification: {"default": 0, "type": "number", "description": "Enable lldp notification", "format": "flag"}
    :param interval: {"description": "Configure lldp notification interval, default is 30 (The lldp notification interval value, default is 30)", "format": "number", "default": 30, "maximum": 3600, "minimum": 5, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "notification-cfg"
        self.DeviceProxy = ""
        self.notification = ""
        self.interval = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TxSet(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param fast_interval: {"description": "Configure lldp tx fast interval value (The lldp tx fast interval value, default is 1)", "format": "number", "default": 1, "maximum": 3600, "minimum": 1, "type": "number"}
    :param fast_count: {"description": "Configure lldp tx fast count value (The lldp tx fast count value, default is 4)", "format": "number", "default": 4, "maximum": 8, "minimum": 1, "type": "number"}
    :param hold: {"description": "Configure lldp tx hold multiplier (The lldp tx hold value, default is 4)", "format": "number", "default": 4, "maximum": 10, "minimum": 1, "type": "number"}
    :param tx_interval: {"description": "Configure lldp tx interval (The lldp tx interval value, default is 30)", "format": "number", "default": 30, "maximum": 3600, "minimum": 1, "type": "number"}
    :param reinit_delay: {"description": "Configure lldp tx reinit delay (The lldp tx reinit_delay value, default is 2)", "format": "number", "default": 2, "maximum": 10, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "tx-set"
        self.DeviceProxy = ""
        self.fast_interval = ""
        self.fast_count = ""
        self.hold = ""
        self.tx_interval = ""
        self.reinit_delay = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EnableCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param enable: {"default": 0, "type": "number", "description": "Enable lldp", "format": "flag"}
    :param rx: {"default": 0, "type": "number", "description": "Enable lldp rx", "format": "flag"}
    :param tx: {"default": 0, "type": "number", "description": "Enable lldp tx", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "enable-cfg"
        self.DeviceProxy = ""
        self.enable = ""
        self.rx = ""
        self.tx = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Lldp(A10BaseClass):
    
    """Class Description::
    Configure LLDP.

    Class lldp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param system_description: {"description": "Configure lldp system description", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param system_name: {"description": "Configure lldp system name", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/lldp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "lldp"
        self.a10_url="/axapi/v3/network/lldp"
        self.DeviceProxy = ""
        self.system_description = ""
        self.notification_cfg = {}
        self.management_address = {}
        self.tx_set = {}
        self.enable_cfg = {}
        self.system_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpNatListCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_nat_list: {"default": 0, "type": "number", "description": "IP NAT list", "format": "flag"}
    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nat-list-cfg"
        self.DeviceProxy = ""
        self.ip_nat_list = ""
        self.route_map = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Lw4O6Cfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param lw4o6: {"default": 0, "type": "number", "description": "LW4O6 Prefix", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "lw4o6-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.lw4o6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Nat64Cfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nat64: {"default": 0, "type": "number", "description": "NAT64 Prefix", "format": "flag"}
    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "nat64-cfg"
        self.DeviceProxy = ""
        self.nat64 = ""
        self.route_map = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ConnectedCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param connected: {"default": 0, "type": "number", "description": "Connected", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "connected-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.connected = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpNatCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param ip_nat: {"default": 0, "type": "number", "description": "IP NAT", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nat-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.ip_nat = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FloatingIpCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param floating_ip: {"default": 0, "type": "number", "description": "Floating IP", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "floating-ip-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.floating_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IsisCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param isis: {"default": 0, "type": "number", "description": "ISO IS-IS", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "isis-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.isis = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OnlyNotFlaggedCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param only_not_flagged: {"default": 0, "type": "number", "description": "Only not flagged", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "only-not-flagged-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.only_not_flagged = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OnlyFlaggedCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param only_flagged: {"default": 0, "type": "number", "description": "Selected Virtual IP (VIP)", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "only-flagged-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.only_flagged = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vip(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vip"
        self.DeviceProxy = ""
        self.only_not_flagged_cfg = {}
        self.only_flagged_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RipCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param rip: {"default": 0, "type": "number", "description": "Routing Information Protocol (RIP)", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rip-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.rip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OspfCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param ospf: {"default": 0, "type": "number", "description": "Open Shortest Path First (OSPF)", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ospf-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.ospf = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class StaticCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route map reference (Pointer to route-map entries)", "format": "string"}
    :param static: {"default": 0, "type": "number", "description": "Static routes", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "static-cfg"
        self.DeviceProxy = ""
        self.route_map = ""
        self.static = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Redistribute(A10BaseClass):
    
    """Class Description::
    Redistribute information from another routing protocol.

    Class redistribute supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}/address-family/ipv6/redistribute`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "redistribute"
        self.a10_url="/axapi/v3/router/bgp/{as_number}/address-family/ipv6/redistribute"
        self.DeviceProxy = ""
        self.ip_nat_list_cfg = {}
        self.lw4o6_cfg = {}
        self.nat64_cfg = {}
        self.connected_cfg = {}
        self.ip_nat_cfg = {}
        self.floating_ip_cfg = {}
        self.isis_cfg = {}
        self.vip = {}
        self.rip_cfg = {}
        self.ospf_cfg = {}
        self.static_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RipMaximumPrefixCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param maximum_prefix: {"description": "Set the maximum number of RIP routes", "minimum": 1, "type": "number", "maximum": 2048, "format": "number"}
    :param maximum_prefix_thres: {"description": "Percentage of maximum routes to generate a warning (Default 75%)", "format": "number", "default": 75, "maximum": 100, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rip-maximum-prefix-cfg"
        self.DeviceProxy = ""
        self.maximum_prefix = ""
        self.maximum_prefix_thres = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RouteCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param route: {"type": "string", "description": "Static route advertisement (debugging purpose) (IP prefix network/length)", "format": "ipv4-cidr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "route-cfg"
        self.DeviceProxy = ""
        self.route = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PassiveInterfaceList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "passive-interface-list"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.trunk = ""
        self.ve = ""
        self.loopback = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NetworkInterfaceListCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "network-interface-list-cfg"
        self.DeviceProxy = ""
        self.ethernet = ""
        self.trunk = ""
        self.ve = ""
        self.loopback = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TimersCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param val_3: {"description": "Garbage collection timer. Default is 120", "minimum": 5, "type": "number", "maximum": 2147483647, "format": "number"}
    :param val_2: {"description": "Routing information timeout timer. Default is 180", "minimum": 5, "type": "number", "maximum": 2147483647, "format": "number"}
    :param basic: {"description": "Basic routing protocol update timers (Routing table update timer value in second. Default is 30)", "minimum": 5, "type": "number", "maximum": 2147483647, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "timers-cfg"
        self.DeviceProxy = ""
        self.val_3 = ""
        self.val_2 = ""
        self.basic = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Timers(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "timers"
        self.DeviceProxy = ""
        self.timers_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Neighbor(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param value: {"type": "string", "description": "Neighbor address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor"
        self.DeviceProxy = ""
        self.value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AclCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param metric: {"description": "Metric value", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param acl: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}
    :param offset_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming updates; 'out': Filter outgoing updates; ", "format": "enum"}
    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "acl-cfg"
        self.DeviceProxy = ""
        self.ve = ""
        self.loopback = ""
        self.metric = ""
        self.trunk = ""
        self.acl = ""
        self.offset_list_direction = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OffsetList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}, "metric": {"description": "Metric value", "minimum": 0, "type": "number", "maximum": 16, "format": "number"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "acl": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}, "offset-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming updates; 'out': Filter outgoing updates; ", "format": "enum"}, "ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "offset-list"
        self.DeviceProxy = ""
        self.acl_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AclCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}
    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param acl: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "acl-cfg"
        self.DeviceProxy = ""
        self.acl_direction = ""
        self.ve = ""
        self.loopback = ""
        self.acl = ""
        self.trunk = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PrefixCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ve: {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}
    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param prefix_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter prefixes in routing updates (Name of a prefix list)", "format": "string"}
    :param trunk: {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}
    :param prefix_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}
    :param ethernet: {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prefix-cfg"
        self.DeviceProxy = ""
        self.ve = ""
        self.loopback = ""
        self.prefix_list = ""
        self.trunk = ""
        self.prefix_list_direction = ""
        self.ethernet = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Prefix(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param prefix_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}, "prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter prefixes in routing updates (Name of a prefix list)", "format": "string"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}, "ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prefix"
        self.DeviceProxy = ""
        self.prefix_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DistributeList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"acl-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': Filter incoming routing updates; 'out': Filter outgoing routing updates; ", "format": "enum"}, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}, "acl": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access-list name", "format": "string"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distribute-list"
        self.DeviceProxy = ""
        self.acl_cfg = []
        self.prefix = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DistanceListCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distance: {"description": "Administrative distance (Distance value)", "format": "number", "default": 120, "maximum": 255, "minimum": 1, "type": "number"}
    :param distance_acl: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access list name", "format": "string"}
    :param distance_ipv4_mask: {"type": "string", "description": "IP source prefix", "format": "ipv4-cidr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distance-list-cfg"
        self.DeviceProxy = ""
        self.distance = ""
        self.distance_acl = ""
        self.distance_ipv4_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NetworkAddresses(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param network_ipv4_mask: {"type": "string", "description": "IP prefix network/length, e.g., 35.0.0.0/8", "format": "ipv4-cidr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "network-addresses"
        self.DeviceProxy = ""
        self.network_ipv4_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Rip(A10BaseClass):
    
    """Class Description::
    Routing Information Protocol (RIP).

    Class rip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param default_metric: {"description": "Set a metric of redistribute routes (Default metric)", "format": "number", "default": 1, "optional": true, "maximum": 16, "minimum": 1, "type": "number"}
    :param recv_buffer_size: {"description": "Set the RIP UDP receive buffer size (the RIP UDP receive buffer size value)", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 8192, "optional": true}
    :param cisco_metric_behavior: {"optional": true, "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enables updating metric consistent with Cisco; 'disable': Disables updating metric consistent with Cisco;  (Enable/Disable updating metric consistent with Cisco)", "format": "enum"}
    :param route_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"route": {"type": "string", "description": "Static route advertisement (debugging purpose) (IP prefix network/length)", "format": "ipv4-cidr"}, "optional": true}}]}
    :param passive_interface_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "optional": true, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}}}]}
    :param network_interface_list_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet": {"type": "number", "description": "Ethernet interface (Port number)", "format": "interface"}, "trunk": {"type": "number", "description": "Trunk interface (Trunk interface number)", "format": "interface"}, "optional": true, "ve": {"type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "format": "interface"}, "loopback": {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}}}]}
    :param version: {"description": "Set routing protocol version (RIP version)", "format": "number", "default": 2, "optional": true, "maximum": 2, "minimum": 1, "type": "number"}
    :param neighbor: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "value": {"type": "string", "description": "Neighbor address", "format": "ipv4-address"}}}]}
    :param default_information: {"optional": true, "enum": ["originate"], "type": "string", "description": "'originate': originate;  (Distribute default route)", "format": "enum"}
    :param distance_list_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distance": {"description": "Administrative distance (Distance value)", "format": "number", "default": 120, "maximum": 255, "minimum": 1, "type": "number"}, "optional": true, "distance-acl": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access list name", "format": "string"}, "distance-ipv4-mask": {"type": "string", "description": "IP source prefix", "format": "ipv4-cidr"}}}]}
    :param network_addresses: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"network-ipv4-mask": {"type": "string", "description": "IP prefix network/length, e.g., 35.0.0.0/8", "format": "ipv4-cidr"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/rip`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rip"
        self.a10_url="/axapi/v3/router/rip"
        self.DeviceProxy = ""
        self.default_metric = ""
        self.recv_buffer_size = ""
        self.cisco_metric_behavior = ""
        self.rip_maximum_prefix_cfg = {}
        self.route_cfg = []
        self.passive_interface_list = []
        self.redistribute = {}
        self.network_interface_list_cfg = []
        self.version = ""
        self.timers = {}
        self.neighbor = []
        self.offset_list = {}
        self.default_information = ""
        self.distribute_list = {}
        self.distance_list_cfg = []
        self.network_addresses = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Aam(A10BaseClass):
    
    """Class Description::
    Configure AAM related settings.

    Class aam supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param aaa_policy_list: {"minItems": 1, "items": {"type": "aaa-policy"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"aaa-rule-list": {"minItems": 1, "items": {"type": "aaa-rule"}, "uniqueItems": true, "array": [{"required": ["index"], "properties": {"index": {"description": "Specify AAA rule index", "format": "number", "type": "number", "maximum": 256, "minimum": 1, "optional": false}, "authorize-policy": {"description": "Specify authorization policy to bind to the AAA rule", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authorization/policy"}, "uri": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "match-type": {"enum": ["contains", "ends-with", "equals", "starts-with"], "type": "string", "description": "'contains': Match URI if request URI contains specified URI; 'ends-with': Match URI if request URI ends with specified URI; 'equals': Match URI if request URI equals specified URI; 'starts-with': Match URI if request URI starts with specified URI; ", "format": "enum"}, "uri-str": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify URI string", "format": "string-rlx"}}}]}, "action": {"optional": true, "enum": ["allow", "deny"], "type": "string", "description": "'allow': Allow traffic that matches this rule; 'deny': Deny traffic that matches this rule; ", "format": "enum"}, "domain-name": {"description": "Specify domain name to bind to the AAA rule (ex: a10networks.com, www.a10networks.com)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "authentication-template": {"description": "Specify authentication template name to bind to the AAA rule", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/template"}, "access-list": {"type": "object", "properties": {"acl-name": {"not": "acl-id", "enum": ["ip-name", "ipv6-name"], "type": "string", "description": "'ip-name': Apply an IP named access list; 'ipv6-name': Apply an IPv6 named access list; ", "format": "enum"}, "acl-id": {"description": "ACL id", "format": "number", "maximum": 199, "$ref-list": ["/axapi/v3/access-list/standard", "/axapi/v3/access-list/extended"], "minimum": 1, "not": "acl-name", "type": "number"}, "name": {"minLength": 1, "maxLength": 16, "type": "string", "description": "Specify Named Access List", "format": "string"}}}}}], "type": "array", "$ref": "/axapi/v3/aam/aaa-policy/{name}/aaa-rule/{index}"}, "name": {"description": "Specify AAA policy name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/aam/aaa-policy/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "aam"
        self.a10_url="/axapi/v3/aam"
        self.DeviceProxy = ""
        self.authentication = {}
        self.aaa_policy_list = []
        self.authorization = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Lacp(A10BaseClass):
    
    """Class Description::
    LACP commands.

    Class lacp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param system_priority: {"description": "LACP system priority. help-val LACP system priority, 1-65535, default 32768", "format": "number", "default": 32768, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/lacp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "lacp"
        self.a10_url="/axapi/v3/lacp"
        self.DeviceProxy = ""
        self.system_priority = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class NewPwdCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param new_password: {"default": 0, "type": "number", "description": "Configure new password text in default change password page", "format": "flag"}
    :param new_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param new_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param new_color_name: {"not": "new-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param new_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param new_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "new-color-name", "type": "string"}
    :param new_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new password text (Default: New Password)", "format": "string-rlx"}
    :param new_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "new-face", "type": "string"}
    :param new_face: {"not": "new-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "new-pwd-cfg"
        self.DeviceProxy = ""
        self.new_password = ""
        self.new_size = ""
        self.new_font = ""
        self.new_color_name = ""
        self.new_color = ""
        self.new_color_value = ""
        self.new_text = ""
        self.new_font_custom = ""
        self.new_face = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class WelcomeMsgCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param wel_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "wel-color-name", "type": "string"}
    :param wel_color_name: {"not": "wel-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param wel_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "wel-face", "type": "string"}
    :param wel_face: {"not": "wel-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param wel_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param wel_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param wel_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param wel_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify welcome message (Default: Please change your password.)", "format": "string-rlx"}
    :param welcome_msg: {"default": 0, "type": "number", "description": "Configure welcome message in default change password page", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "welcome-msg-cfg"
        self.DeviceProxy = ""
        self.wel_color_value = ""
        self.wel_color_name = ""
        self.wel_font_custom = ""
        self.wel_face = ""
        self.wel_font = ""
        self.wel_size = ""
        self.wel_color = ""
        self.wel_text = ""
        self.welcome_msg = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TitleCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param title: {"default": 0, "type": "number", "description": "Configure title in default change password page", "format": "flag"}
    :param title_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param title_color_name: {"not": "title-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param title_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "title-face", "type": "string"}
    :param title_face: {"not": "title-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param title_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "title-color-name", "type": "string"}
    :param title_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param title_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify title", "format": "string-rlx"}
    :param title_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "title-cfg"
        self.DeviceProxy = ""
        self.title = ""
        self.title_color = ""
        self.title_color_name = ""
        self.title_font_custom = ""
        self.title_face = ""
        self.title_color_value = ""
        self.title_size = ""
        self.title_text = ""
        self.title_font = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class OldPwdCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param old_face: {"not": "old-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param old_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param old_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "old-color-name", "type": "string"}
    :param old_password: {"default": 0, "type": "number", "description": "Configure old password text in default change password page", "format": "flag"}
    :param old_color_name: {"not": "old-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param old_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param old_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify old password text (Default: Old Password)", "format": "string-rlx"}
    :param old_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "old-face", "type": "string"}
    :param old_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "old-pwd-cfg"
        self.DeviceProxy = ""
        self.old_face = ""
        self.old_color = ""
        self.old_color_value = ""
        self.old_password = ""
        self.old_color_name = ""
        self.old_size = ""
        self.old_text = ""
        self.old_font_custom = ""
        self.old_font = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Background(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bgfile: {"description": "Specify background image filename", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "bgcolor", "type": "string"}
    :param bgstyle: {"enum": ["tile", "stretch", "fit"], "type": "string", "description": "'tile': Tile; 'stretch': Stretch; 'fit': Fit; ", "format": "enum"}
    :param bgcolor_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "bgcolor-name", "type": "string"}
    :param bgcolor_name: {"not": "bgcolor-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param bgcolor: {"default": 0, "not": "bgfile", "type": "number", "description": "Specify background color", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "background"
        self.DeviceProxy = ""
        self.bgfile = ""
        self.bgstyle = ""
        self.bgcolor_value = ""
        self.bgcolor_name = ""
        self.bgcolor = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CfmPwdCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cfm_color_name: {"not": "cfm-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param cfm_face: {"not": "cfm-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param cfm_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "cfm-color-name", "type": "string"}
    :param cfm_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "cfm-face", "type": "string"}
    :param cfm_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param cfm_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param cfm_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify confirm password text (Default: Confirm New Password)", "format": "string-rlx"}
    :param confirm_password: {"default": 0, "type": "number", "description": "Configure confirm password text in default change password page", "format": "flag"}
    :param cfm_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cfm-pwd-cfg"
        self.DeviceProxy = ""
        self.cfm_color_name = ""
        self.cfm_face = ""
        self.cfm_color_value = ""
        self.cfm_font_custom = ""
        self.cfm_size = ""
        self.cfm_font = ""
        self.cfm_text = ""
        self.confirm_password = ""
        self.cfm_color = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class UsernameCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param username: {"default": 0, "type": "number", "description": "Configure username text in default change password page", "format": "flag"}
    :param user_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param user_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username text (Default: Username)", "format": "string-rlx"}
    :param user_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param user_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "user-color-name", "type": "string"}
    :param user_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "user-face", "type": "string"}
    :param user_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param user_face: {"not": "user-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param user_color_name: {"not": "user-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "username-cfg"
        self.DeviceProxy = ""
        self.username = ""
        self.user_font = ""
        self.user_text = ""
        self.user_size = ""
        self.user_color_value = ""
        self.user_font_custom = ""
        self.user_color = ""
        self.user_face = ""
        self.user_color_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NoteCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param note_text: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify notes", "format": "string-rlx"}
    :param note_color_value: {"description": "Specify 6-digit HEX color value", "format": "string", "minLength": 6, "maxLength": 6, "not": "note-color-name", "type": "string"}
    :param note_face: {"not": "note-font-custom", "enum": ["Arial", "Courier_New", "Georgia", "Times_New_Roman", "Verdana"], "type": "string", "description": "'Arial': Arial; 'Courier_New': Courier New; 'Georgia': Georgia; 'Times_New_Roman': Times New Roman; 'Verdana': Verdana; ", "format": "enum"}
    :param note_font: {"default": 0, "type": "number", "description": "Sepcify font", "format": "flag"}
    :param note_color: {"default": 0, "type": "number", "description": "Specify font color", "format": "flag"}
    :param note_size: {"description": "Specify font size", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}
    :param note: {"default": 0, "type": "number", "description": "Configure notes in default change password page", "format": "flag"}
    :param note_font_custom: {"description": "Specify custom font", "format": "string-rlx", "minLength": 1, "maxLength": 63, "not": "note-face", "type": "string"}
    :param note_color_name: {"not": "note-color-value", "enum": ["aqua", "black", "blue", "fuchsia", "gray", "green", "lime", "maroon", "navy", "olive", "orange", "purple", "red", "silver", "teal", "white", "yellow"], "type": "string", "description": "'aqua': aqua; 'black': black; 'blue': blue; 'fuchsia': fuchsia; 'gray': gray; 'green': green; 'lime': lime; 'maroon': maroon; 'navy': navy; 'olive': olive; 'orange': orange; 'purple': purple; 'red': red; 'silver': silver; 'teal': teal; 'white': white; 'yellow': yellow; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "note-cfg"
        self.DeviceProxy = ""
        self.note_text = ""
        self.note_color_value = ""
        self.note_face = ""
        self.note_font = ""
        self.note_color = ""
        self.note_size = ""
        self.note = ""
        self.note_font_custom = ""
        self.note_color_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ChangePassword(A10BaseClass):
    
    """Class Description::
    Change password page configuration.

    Class change-password supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action_url: {"description": "Specify form action URL in default change password page (Default: /change.fo)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param new_password_var: {"description": "Specify new password variable name in default change password page (Default: cp_new_pwd)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param submit_text: {"description": "Specify submit button text in default change password page (Default: Submit)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param confirm_password_var: {"description": "Specify confirm password variable name in default change password page (Default: cp_cfm_pwd)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param reset_text: {"description": "Specify reset button text in default change password page (Default: Reset)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param username_var: {"description": "Specify username variable name in default change password page (Default: cp_usr)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param old_password_var: {"description": "Specify old password variable name in default change password page (Default: cp_old_pwd)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/portal/{name}/change-password`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "change-password"
        self.a10_url="/axapi/v3/aam/authentication/portal/{name}/change-password"
        self.DeviceProxy = ""
        self.action_url = ""
        self.new_password_var = ""
        self.new_pwd_cfg = {}
        self.submit_text = ""
        self.welcome_msg_cfg = {}
        self.confirm_password_var = ""
        self.title_cfg = {}
        self.reset_text = ""
        self.username_var = ""
        self.old_pwd_cfg = {}
        self.background = {}
        self.old_password_var = ""
        self.cfm_pwd_cfg = {}
        self.username_cfg = {}
        self.note_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param packets_err_icv_check: {"optional": true, "size": "4", "type": "number", "oid": "9", "format": "counter"}
    :param packets_err_lifetime_lifebytes: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param packets_err_badspi: {"optional": true, "size": "4", "type": "number", "oid": "10", "format": "counter"}
    :param cavium_err_enc: {"optional": true, "size": "4", "type": "number", "oid": "18", "format": "counter"}
    :param bytes_encrypted: {"optional": true, "size": "4", "type": "number", "oid": "12", "format": "counter"}
    :param anti_replay_num: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param prefrag_error: {"optional": true, "size": "4", "type": "number", "oid": "15", "format": "counter"}
    :param packets_err_encryption: {"optional": true, "size": "4", "type": "number", "oid": "6", "format": "counter"}
    :param rekey_num: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param frags_created: {"optional": true, "size": "4", "type": "number", "oid": "16", "format": "counter"}
    :param packets_err_inactive: {"optional": true, "size": "4", "type": "number", "oid": "5", "format": "counter"}
    :param prefrag_success: {"optional": true, "size": "4", "type": "number", "oid": "14", "format": "counter"}
    :param packets_err_pad_check: {"optional": true, "size": "4", "type": "number", "oid": "7", "format": "counter"}
    :param packets_err_pkt_sanity: {"optional": true, "size": "4", "type": "number", "oid": "8", "format": "counter"}
    :param packets_decrypted: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param frags_reassembled: {"optional": true, "size": "4", "type": "number", "oid": "17", "format": "counter"}
    :param packets_encrypted: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param cavium_err_dec: {"optional": true, "size": "4", "type": "number", "oid": "19", "format": "counter"}
    :param bytes_decrypted: {"optional": true, "size": "4", "type": "number", "oid": "13", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.packets_err_icv_check = ""
        self.packets_err_lifetime_lifebytes = ""
        self.packets_err_badspi = ""
        self.cavium_err_enc = ""
        self.bytes_encrypted = ""
        self.anti_replay_num = ""
        self.prefrag_error = ""
        self.packets_err_encryption = ""
        self.rekey_num = ""
        self.frags_created = ""
        self.packets_err_inactive = ""
        self.prefrag_success = ""
        self.packets_err_pad_check = ""
        self.packets_err_pkt_sanity = ""
        self.packets_decrypted = ""
        self.frags_reassembled = ""
        self.packets_encrypted = ""
        self.cavium_err_dec = ""
        self.bytes_decrypted = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipsec(A10BaseClass):
    
    """Class Description::
    Statistics for the object ipsec.

    Class ipsec supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "IPsec name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn/ipsec/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ipsec"
        self.a10_url="/axapi/v3/vpn/ipsec/{name}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IntervalCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param interval: {"description": "Transmit interval between BFD packets. help-val Milliseconds", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}
    :param min_rx: {"description": "Minimum receive interval capability. help-val Milliseconds", "minimum": 48, "type": "number", "maximum": 1000, "format": "number"}
    :param multiplier: {"description": "Multiplier value used to compute holddown. help-val value used to multiply the interval", "minimum": 3, "type": "number", "maximum": 50, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "interval-cfg"
        self.DeviceProxy = ""
        self.interval = ""
        self.min_rx = ""
        self.multiplier = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bfd(A10BaseClass):
    
    """Class Description::
    Configure BFD (Bidirectional Forwarding Detection).

    Class bfd supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param enable: {"default": 0, "optional": true, "type": "number", "description": "Enable BFD", "format": "flag"}
    :param echo: {"default": 0, "optional": true, "type": "number", "description": "Enable BFD Echo", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/bfd`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "bfd"
        self.a10_url="/axapi/v3/bfd"
        self.DeviceProxy = ""
        self.interval_cfg = {}
        self.enable = ""
        self.echo = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DnsPtrRecord(A10BaseClass):
    
    """Class Description::
    Specify DNS PTR Record.

    Class dns-ptr-record supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ptr_name: {"description": "Specify Domain Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param ttl: {"optional": true, "type": "number", "description": "Specify TTL", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-ptr-record/{ptr_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ptr_name"]

        self.b_key = "dns-ptr-record"
        self.a10_url="/axapi/v3/gslb/zone/{name}/service/{service_port}+{service_name}/dns-ptr-record/{ptr_name}"
        self.DeviceProxy = ""
        self.ptr_name = ""
        self.ttl = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HttpAlg(A10BaseClass):
    
    """Class Description::
    HTTP-ALG Template.

    Class http-alg supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param header_name_client_ip: {"description": "Header name (default: X-Forwarded-For)", "format": "string", "default": "X-Forwarded-For", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param retry: {"description": "Specify the maximum retries allowed for sending an request to a RADIUS server (default 2) (The maximum retries allowed for sending an request to the radius server (default 2))", "format": "number", "default": 2, "optional": true, "maximum": 3, "minimum": 0, "type": "number"}
    :param retry_svr_num: {"description": "Specify the maximum RADIUS servers allowed to try (default 0)", "format": "number", "default": 0, "optional": true, "maximum": 1, "minimum": 0, "type": "number"}
    :param name: {"description": "HTTP-ALG template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param request_insert_msisdn: {"default": 0, "optional": true, "type": "number", "description": "Insert MSISDN into HTTP request", "format": "flag"}
    :param radius_sg: {"description": "RADIUS service group (RADIUS service group name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/service-group"}
    :param encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}
    :param request_insert_client_ip: {"default": 0, "optional": true, "type": "number", "description": "Insert Client IP into HTTP request", "format": "flag"}
    :param header_name_msisdn: {"description": "Header name (default: X-MSISDN)", "format": "string", "default": "X-MSISDN", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param timeout: {"description": "The maximum time allowed for waiting for a response from a radius server (default 2)", "format": "number", "default": 2, "optional": true, "maximum": 3, "minimum": 1, "type": "number"}
    :param include_tunnel_ip: {"default": 0, "optional": true, "type": "number", "description": "Include the tunnel IP (applies to DS-Lite and 6RD-NAT64 sessions)", "format": "flag"}
    :param method: {"description": "'append': Append if there is already a header (default); 'replace': Replace if there is already a header; ", "format": "enum", "default": "append", "type": "string", "enum": ["append", "replace"], "optional": true}
    :param secret_string: {"description": "The RADIUS secret", "format": "password", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/template/http-alg/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "http-alg"
        self.a10_url="/axapi/v3/cgnv6/template/http-alg/{name}"
        self.DeviceProxy = ""
        self.header_name_client_ip = ""
        self.retry = ""
        self.retry_svr_num = ""
        self.name = ""
        self.request_insert_msisdn = ""
        self.radius_sg = ""
        self.encrypted = ""
        self.request_insert_client_ip = ""
        self.header_name_msisdn = ""
        self.timeout = ""
        self.include_tunnel_ip = ""
        self.method = ""
        self.secret_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hits: {"description": "Number of times the service IP has been selected", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param recent: {"description": "Recent hits", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.hits = ""
        self.recent = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceIp(A10BaseClass):
    
    """Class Description::
    Statistics for the object service-ip.

    Class service-ip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param node_name: {"description": "Service-IP Name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param port_list: {"minItems": 1, "items": {"type": "port"}, "uniqueItems": true, "array": [{"required": ["port-num", "port-proto"], "properties": {"port-proto": {"enum": ["tcp", "udp"], "description": "'tcp': TCP Port; 'udp': UDP Port; ", "format": "enum", "type": "string", "oid": "1002", "optional": false}, "stats": {"type": "object", "properties": {"active": {"description": "Active Servers", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}, "current": {"description": "Current Connections", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}}}, "port-num": {"description": "Port Number", "format": "number", "optional": false, "oid": "1001", "maximum": 65534, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/gslb/service-ip/{node-name}/port/{port-num}+{port-proto}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/service-ip/{node_name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "node_name"]

        self.b_key = "service-ip"
        self.a10_url="/axapi/v3/gslb/service-ip/{node_name}/stats"
        self.DeviceProxy = ""
        self.node_name = ""
        self.port_list = []
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Sync(A10BaseClass):
    
    """    :param all_partitions: {"default": 0, "optional": true, "type": "number", "description": "All partition configurations", "format": "flag"}
    :param partition_name: {"description": "Partition name", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param auto_authentication: {"default": 0, "optional": true, "type": "number", "description": "Authenticate with local username and password", "format": "flag"}
    :param address: {"optional": true, "type": "string", "description": "Specify the destination ip address to sync", "format": "ipv4-address"}
    :param shared: {"default": 0, "optional": true, "type": "number", "description": "Shared partition", "format": "flag"}
    :param type: {"optional": true, "enum": ["running", "all"], "type": "string", "description": "'running': Sync local running to peer's running configuration; 'all': Sync local running to peer's running configuration, and local startup to peer's startup configuration; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Sync operation.

    Class sync supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/configure/sync`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "sync"
        self.a10_url="/axapi/v3/configure/sync"
        self.DeviceProxy = ""
        self.all_partitions = ""
        self.partition_name = ""
        self.auto_authentication = ""
        self.address = ""
        self.shared = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Netflow(A10BaseClass):
    
    """Class Description::
    Configure NetFlow/IPFIX.

    Class netflow supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param monitor_list: {"minItems": 1, "items": {"type": "monitor"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"source-ip-use-mgmt": {"default": 0, "optional": true, "type": "number", "description": "Use management interface's IP address for source ip of netflow packets", "format": "flag"}, "protocol": {"description": "'v9': Netflow version 9; 'v10': Netflow version 10 (IPFIX); ", "format": "enum", "default": "v9", "type": "string", "enum": ["v9", "v10"], "optional": true}, "name": {"description": "Name of netflow monitor", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "source-address": {"type": "object", "properties": {"ip": {"type": "string", "description": "Specify source IP address", "format": "ipv4-address"}, "ipv6": {"type": "string", "description": "Specify source IPv6 address", "format": "ipv6-address"}}}, "destination": {"type": "object", "properties": {"ip-cfg": {"type": "object", "properties": {"ip": {"not-list": ["service-group", "ipv6"], "type": "string", "description": "IP address of netflow collector", "format": "ipv4-address"}, "port4": {"description": "Port number, default is 9996", "format": "number", "default": 9996, "maximum": 65535, "minimum": 1, "type": "number"}}}, "service-group": {"description": "Service-group for load balancing between multiple collector servers", "format": "string-rlx", "minLength": 1, "not-list": ["ip", "ipv6"], "maxLength": 63, "type": "string"}, "ipv6-cfg": {"type": "object", "properties": {"port6": {"description": "Port number, default is 9996", "format": "number", "default": 9996, "maximum": 65535, "minimum": 1, "type": "number"}, "ipv6": {"not-list": ["service-group", "ip"], "type": "string", "description": "IPv6 address of netflow collector", "format": "ipv6-address"}}}}}, "sample": {"type": "object", "properties": {"ve-list": {"minItems": 1, "items": {"type": "ve"}, "uniqueItems": true, "array": [{"required": ["ve-num"], "properties": {"ve-num": {"description": "VE interface number", "format": "number", "optional": false, "maximum": 4094, "minimum": 2, "type": "number", "$ref": "/axapi/v3/interface/ve"}}}], "type": "array", "$ref": "/axapi/v3/netflow/monitor/{name}/sample/ve/{ve-num}"}, "nat-pool-list": {"minItems": 1, "items": {"type": "nat-pool"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"pool-name": {"description": "Name of nat pool", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/netflow/monitor/{name}/sample/nat-pool/{pool-name}"}, "ethernet-list": {"minItems": 1, "items": {"type": "ethernet"}, "uniqueItems": true, "array": [{"required": ["ifindex"], "properties": {"ifindex": {"optional": false, "$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet interface number", "format": "interface"}}}], "type": "array", "$ref": "/axapi/v3/netflow/monitor/{name}/sample/ethernet/{ifindex}"}}}, "record": {"type": "object", "properties": {"sesn-event-nat64": {"enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}, "nat64": {"default": 0, "type": "number", "description": "NAT64 Flow Record Template", "format": "flag"}, "dslite": {"default": 0, "type": "number", "description": "DS-Lite Flow Record Template", "format": "flag"}, "nat44": {"default": 0, "type": "number", "description": "NAT44 Flow Record Template", "format": "flag"}, "netflow-v5-ext": {"default": 0, "type": "number", "description": "Extended NetFlow V5 Flow Record Template, supports ipv6", "format": "flag"}, "port-mapping-nat64": {"enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}, "sesn-event-dslite": {"enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}, "sesn-event-nat44": {"enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}, "netflow-v5": {"default": 0, "type": "number", "description": "NetFlow V5 Flow Record Template", "format": "flag"}, "port-mapping-dslite": {"enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}, "port-mapping-nat44": {"enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}}}, "disable": {"default": 0, "optional": true, "type": "number", "description": "Disable this netflow monitor", "format": "flag"}, "resend-template": {"type": "object", "properties": {"records": {"description": "To resend template once for each number of records (Number of records: default is 1000, 0 means never resend template)", "format": "number", "default": 1000, "maximum": 1000000, "minimum": 0, "type": "number"}, "timeout": {"description": "To set time interval to resend template (number of seconds: default is 1800, 0 means never resend template)", "format": "number", "default": 1800, "maximum": 86400, "minimum": 0, "type": "number"}}}, "flow-timeout": {"description": "Configure timeout value to export flow records periodically for long-live session ( Number of minutes: default is 10, 0 means only send flow record when session is deleted)", "format": "number", "default": 10, "optional": true, "maximum": 1440, "minimum": 0, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/netflow/monitor/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "netflow"
        self.a10_url="/axapi/v3/netflow"
        self.DeviceProxy = ""
        self.monitor_list = []
        self.common = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """Class Description::
    Specify the RADIUS server's hostname or IP address.

    Class host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv4_list: {"minItems": 1, "items": {"type": "ipv4"}, "uniqueItems": true, "array": [{"required": ["ipv4-addr"], "properties": {"ipv4-addr": {"optional": false, "type": "string", "description": "IPV4 address of RADIUS server", "format": "ipv4-address"}, "secret": {"type": "object", "properties": {"port-cfg": {"type": "object", "properties": {"acct-port": {"description": "Specify the RADIUS server's accounting port (default 1813)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "retransmit": {"description": "Specify the maximum times allowed for resending an request to the radius server (default 3)", "format": "number", "default": 3, "maximum": 5, "minimum": 0, "type": "number"}, "timeout": {"description": "Specify the maximum time allowed for waiting for a response from a radius server (default 3)", "format": "number", "default": 3, "maximum": 15, "minimum": 1, "type": "number"}, "auth-port": {"description": "Specify the RADIUS server's authentication port (default 1812)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "encrypted": {"type": "encrypted", "description": " Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "secret-value": {"minLength": 1, "maxLength": 128, "type": "string", "description": "The RADIUS server's secret", "format": "password"}}}}}], "type": "array", "$ref": "/axapi/v3/radius-server/host/ipv4/{ipv4-addr}"}
    :param name_list: {"minItems": 1, "items": {"type": "name"}, "uniqueItems": true, "array": [{"required": ["hostname"], "properties": {"secret": {"type": "object", "properties": {"port-cfg": {"type": "object", "properties": {"acct-port": {"description": "Specify the RADIUS server's accounting port (default 1813)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "retransmit": {"description": "Specify the maximum times allowed for resending an request to the radius server (default 3)", "format": "number", "default": 3, "maximum": 5, "minimum": 0, "type": "number"}, "timeout": {"description": "Specify the maximum time allowed for waiting for a response from a radius server (default 3)", "format": "number", "default": 3, "maximum": 15, "minimum": 1, "type": "number"}, "auth-port": {"description": "Specify the RADIUS server's authentication port (default 1812)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "encrypted": {"type": "encrypted", "description": " Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "secret-value": {"minLength": 1, "maxLength": 128, "type": "string", "description": "The RADIUS server's secret", "format": "password"}}}, "hostname": {"description": "Hostname of RADIUS server", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/radius-server/host/name/{hostname}"}
    :param ipv6_list: {"minItems": 1, "items": {"type": "ipv6"}, "uniqueItems": true, "array": [{"required": ["ipv6-addr"], "properties": {"secret": {"type": "object", "properties": {"port-cfg": {"type": "object", "properties": {"acct-port": {"description": "Specify the RADIUS server's accounting port (default 1813)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "retransmit": {"description": "Specify the maximum times allowed for resending an request to the radius server (default 3)", "format": "number", "default": 3, "maximum": 5, "minimum": 0, "type": "number"}, "timeout": {"description": "Specify the maximum time allowed for waiting for a response from a radius server (default 3)", "format": "number", "default": 3, "maximum": 15, "minimum": 1, "type": "number"}, "auth-port": {"description": "Specify the RADIUS server's authentication port (default 1812)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "encrypted": {"type": "encrypted", "description": " Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "secret-value": {"minLength": 1, "maxLength": 128, "type": "string", "description": "The RADIUS server's secret", "format": "password"}}}, "ipv6-addr": {"optional": false, "type": "string", "description": "IPV6 address of RADIUS server", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/radius-server/host/ipv6/{ipv6-addr}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/radius-server/host`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "host"
        self.a10_url="/axapi/v3/radius-server/host"
        self.DeviceProxy = ""
        self.ipv4_list = []
        self.name_list = []
        self.ipv6_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


